summaryrefslogtreecommitdiffstats
path: root/chrome/browser/speech
diff options
context:
space:
mode:
authorsatish@chromium.org <satish@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-03-02 17:34:54 +0000
committersatish@chromium.org <satish@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-03-02 17:34:54 +0000
commita9266102343c8ca6ef0c07b4b3c3de8f4a3a5600 (patch)
tree03c79d2bb1cb6bc37f6da67962dc9b97b841aaeb /chrome/browser/speech
parent21f175b69f4a74c835f64976d1a41d0ef945984f (diff)
downloadchromium_src-a9266102343c8ca6ef0c07b4b3c3de8f4a3a5600.zip
chromium_src-a9266102343c8ca6ef0c07b4b3c3de8f4a3a5600.tar.gz
chromium_src-a9266102343c8ca6ef0c07b4b3c3de8f4a3a5600.tar.bz2
Change from PROCESS_LAUNCHER to FILE thread per earlier suggestion.
BUG=none TEST=none Review URL: http://codereview.chromium.org/6594120 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@76557 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/speech')
-rw-r--r--chrome/browser/speech/speech_input_manager.cc7
1 files changed, 3 insertions, 4 deletions
diff --git a/chrome/browser/speech/speech_input_manager.cc b/chrome/browser/speech/speech_input_manager.cc
index 2d31697..cbc6f12 100644
--- a/chrome/browser/speech/speech_input_manager.cc
+++ b/chrome/browser/speech/speech_input_manager.cc
@@ -185,11 +185,10 @@ bool SpeechInputManager::IsFeatureEnabled() {
void SpeechInputManager::ShowAudioInputSettings() {
// Since AudioManager::ShowAudioInputSettings can potentially launch external
- // processes, do that in the PROCESS_LAUNCHER thread to not block the calling
- // threads.
- if (!BrowserThread::CurrentlyOn(BrowserThread::PROCESS_LAUNCHER)) {
+ // processes, do that in the FILE thread to not block the calling threads.
+ if (!BrowserThread::CurrentlyOn(BrowserThread::FILE)) {
BrowserThread::PostTask(
- BrowserThread::PROCESS_LAUNCHER, FROM_HERE,
+ BrowserThread::FILE, FROM_HERE,
NewRunnableFunction(&SpeechInputManager::ShowAudioInputSettings));
return;
}